pub struct BasicChatInputSchema {
pub chat_message: String,
}Expand description
Basic chat input schema.
Fields
chat_message: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for BasicChatInputSchema
impl<'de> Deserialize<'de> for BasicChatInputSchema
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BasicChatInputSchema
impl JsonSchema for BasicChatInputSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for BasicChatInputSchema
impl RefUnwindSafe for BasicChatInputSchema
impl Send for BasicChatInputSchema
impl Sync for BasicChatInputSchema
impl Unpin for BasicChatInputSchema
impl UnsafeUnpin for BasicChatInputSchema
impl UnwindSafe for BasicChatInputSchema